import { DatabaseHelper } from "./DatabaseHelper";

/**
 * Likes helper
 * 
 * @author Pierre HUBERT
 */

/**
 * Types of likes
 */
export enum LikesType {
	USER = "user",
	POST = "post",
	COMMENT = "comment",
	GROUP = "group"
}


const LIKES_TABLE = "aime";


/**
 * Translation of kinds of likes for the database
 */
const LikesKindsDB = [];
LikesKindsDB[LikesType.USER] = "page";
LikesKindsDB[LikesType.POST] = "texte";
LikesKindsDB[LikesType.COMMENT] = "commentaire";
LikesKindsDB[LikesType.GROUP] = "group";



export class LikesHelper {

	/**
	 * Count the number of likes of a specified element
	 * 
	 * @param id The ID of the element to count
	 * @param type The type of the element
	 */
	public static async Count(id: number, type: LikesType) : Promise<number> {
		return DatabaseHelper.Count({
			table: LIKES_TABLE,
			where: {
				ID_type: id,
				type: LikesKindsDB[type]
			}
		})
	}


	/**
	 * Check out whether the user likes an element or not
	 * 
	 * @param userID ID of the user
	 * @param id ID of the thing to check 
	 * @param type The kind of the element
	 */
	public static async IsLiking(userID: number, id: number, type: LikesType) : Promise<boolean> {
		if(userID == 0) return false;

		return await DatabaseHelper.Count({
			table: LIKES_TABLE,
			where: {
				ID_type: id,
				type: LikesKindsDB[type],
				ID_personne: userID
			}
		}) == 1;
	}
}